@@ -1,10 +1,12 @@
 testthat::context("ContractionPipe")
 
-testthat::setup(bdpar.Options$reset())
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
-test_that("initialize",{
+testthat::test_that("initialize",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -37,12 +39,18 @@ test_that("initialize",{
                                               resourcesContractionsPath))
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize propertyName type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- NULL
   propertyLanguageName <- "language"
@@ -64,16 +72,22 @@ testthat::test_that("initialize propertyName type error",{
                                              notAfterDeps,
                                              replaceAbbreviations,
                                              resourcesAbbreviationsPath),
-                         "[ContractionPipe][initialize][Error] Checking the type of the 'propertyName' variable: NULL",
+                         "[ContractionPipe][initialize][FATAL] Checking the type of the 'propertyName' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize propertyLanguageName type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- NULL
@@ -95,16 +109,22 @@ testthat::test_that("initialize propertyLanguageName type error",{
                                              notAfterDeps,
                                              replaceContractions,
                                              resourcesContractionsPath),
-                         "[ContractionPipe][initialize][Error] Checking the type of the 'propertyLanguageName' variable: NULL",
+                         "[ContractionPipe][initialize][FATAL] Checking the type of the 'propertyLanguageName' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize alwaysBeforeDeps type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -126,16 +146,22 @@ testthat::test_that("initialize alwaysBeforeDeps type error",{
                                              notAfterDeps,
                                              replaceContractions,
                                              resourcesContractionsPath),
-                         "[ContractionPipe][initialize][Error] Checking the type of the 'alwaysBeforeDeps' variable: NULL",
+                         "[ContractionPipe][initialize][FATAL] Checking the type of the 'alwaysBeforeDeps' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize notAfterDeps type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -157,16 +183,22 @@ testthat::test_that("initialize notAfterDeps type error",{
                                              notAfterDeps,
                                              replaceContractions,
                                              resourcesContractionsPath),
-                         "[ContractionPipe][initialize][Error] Checking the type of the 'notAfterDeps' variable: NULL",
+                         "[ContractionPipe][initialize][FATAL] Checking the type of the 'notAfterDeps' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize replaceContractions type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -188,16 +220,22 @@ testthat::test_that("initialize replaceContractions type error",{
                                              notAfterDeps,
                                              replaceContractions,
                                              resourcesContractionsPath),
-                         "[ContractionPipe][initialize][Error] Checking the type of the 'replaceContractions' variable: NULL",
+                         "[ContractionPipe][initialize][FATAL] Checking the type of the 'replaceContractions' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("initialize resourcesContractionsPath type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -215,7 +253,7 @@ testthat::test_that("initialize resourcesContractionsPath type error",{
                                              notAfterDeps,
                                              replaceContractions,
                                              resourcesContractionsPath),
-                         "[ContractionPipe][initialize][Error] Path of contractions resources is neither defined in initialize or in bdpar.Options",
+                         "[ContractionPipe][initialize][FATAL] Path of contractions resources is neither defined in initialize or in bdpar.Options",
                          fixed = TRUE)
 
   resourcesContractionsPath <- 1
@@ -226,16 +264,22 @@ testthat::test_that("initialize resourcesContractionsPath type error",{
                                              notAfterDeps,
                                              replaceContractions,
                                              resourcesContractionsPath),
-                         "[ContractionPipe][initialize][Error] Checking the type of the 'resourcesContractionsPath' variable: numeric",
+                         "[ContractionPipe][initialize][FATAL] Checking the type of the 'resourcesContractionsPath' variable: numeric",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -273,12 +317,18 @@ testthat::test_that("pipe",{
   testthat::expect_equal(instance$getSpecificProperty("contractions"),"I'm")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe data empty",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -312,16 +362,22 @@ testthat::test_that("pipe data empty",{
   instance$addProperties("en","language")
 
   testthat::expect_warning(pipe$pipe(instance),
-                           "\\[ContractionPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testContractionPipe\\/testFile\\.tsms has data empty on pipe Contractions")
+                           "\\[ContractionPipe\\]\\[pipe\\]\\[WARN\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testContractionPipe\\/testFile\\.tsms has data empty on pipe Contractions")
 
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe wihtout json file",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -355,15 +411,21 @@ testthat::test_that("pipe wihtout json file",{
   instance$addProperties("en","language")
 
   testthat::expect_warning(pipe$pipe(instance),
-                           "\\[ContractionPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testContractionPipe\\/testFile\\.tsms has not an contractionsJsonFile to apply to the language ->en")
+                           "\\[ContractionPipe\\]\\[pipe\\]\\[WARN\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testContractionPipe\\/testFile\\.tsms has not an contractionsJsonFile to apply to the language ->en")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe wihtout language property",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -396,15 +458,21 @@ testthat::test_that("pipe wihtout language property",{
   instance$setData("I'm tall")
 
   testthat::expect_warning(pipe$pipe(instance),
-                           "\\[ContractionPipe\\]\\[pipe\\]\\[Warning\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testContractionPipe\\/testFile\\.tsms has not language property")
+                           "\\[ContractionPipe\\]\\[pipe\\]\\[WARN\\] The file: [\\\\\\:[:alnum:]\\/_.-]*testFiles\\/testContractionPipe\\/testFile\\.tsms has not language property")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("pipe instance type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -432,16 +500,22 @@ testthat::test_that("pipe instance type error",{
   instance <- NULL
 
   testthat::expect_error(pipe$pipe(instance),
-                         "[ContractionPipe][pipe][Error] Checking the type of the 'instance' variable: NULL",
+                         "[ContractionPipe][pipe][FATAL] Checking the type of the 'instance' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("findContraction",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -475,12 +549,18 @@ testthat::test_that("findContraction",{
 
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("findContraction abbreviation type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -510,16 +590,22 @@ testthat::test_that("findContraction abbreviation type error",{
 
   testthat::expect_error(pipe$findContraction(data,
                                               contraction),
-                         "[ContractionPipe][findContraction][Error] Checking the type of the 'contraction' variable: NULL",
+                         "[ContractionPipe][findContraction][FATAL] Checking the type of the 'contraction' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("findContraction data type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -548,16 +634,22 @@ testthat::test_that("findContraction data type error",{
   data <- NULL
 
   testthat::expect_error(pipe$findContraction(data, contraction),
-                         "[ContractionPipe][findContraction][Error] Checking the type of the 'data' variable: NULL",
+                         "[ContractionPipe][findContraction][FATAL] Checking the type of the 'data' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("replaceContraction ",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -592,12 +684,18 @@ testthat::test_that("replaceContraction ",{
                          " I am  tall")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("replaceContraction contraction type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -629,16 +727,22 @@ testthat::test_that("replaceContraction contraction type error",{
   testthat::expect_error(pipe$replaceContraction(contraction,
                                                  extendedContraction,
                                                  data),
-                         "[ContractionPipe][replaceContraction][Error] Checking the type of the 'contraction' variable: NULL",
+                         "[ContractionPipe][replaceContraction][FATAL] Checking the type of the 'contraction' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("replaceContraction extendedContraction type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -670,16 +774,22 @@ testthat::test_that("replaceContraction extendedContraction type error",{
   testthat::expect_error(pipe$replaceContraction(contraction,
                                                  extendedContraction,
                                                  data),
-                         "[ContractionPipe][replaceContraction][Error] Checking the type of the 'extendedContraction' variable: NULL",
+                         "[ContractionPipe][replaceContraction][FATAL] Checking the type of the 'extendedContraction' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("replaceContraction data type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -711,16 +821,22 @@ testthat::test_that("replaceContraction data type error",{
   testthat::expect_error(pipe$replaceContraction(contraction,
                                                  extendedContraction,
                                                  data),
-                         "[ContractionPipe][replaceContraction][Error] Checking the type of the 'data' variable: NULL",
+                         "[ContractionPipe][replaceContraction][FATAL] Checking the type of the 'data' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("getPropertyLanguageName",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -749,12 +865,18 @@ testthat::test_that("getPropertyLanguageName",{
                          "language")
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("getResourcesContractionsPath",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -789,12 +911,18 @@ testthat::test_that("getResourcesContractionsPath",{
                          path)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("setResourcesContractionsPath",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -829,12 +957,18 @@ testthat::test_that("setResourcesContractionsPath",{
                          path)
 })
 
-testthat::teardown(bdpar.Options$reset())
-testthat::setup(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
+
+testthat::setup({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
 
 testthat::test_that("setResourcesContractionsPath path type error",{
   testthat::skip_if_not_installed("rex")
-  testthat::skip_if_not_installed("textutils")
   testthat::skip_if_not_installed("rjson")
   propertyName <- "contractions"
   propertyLanguageName <- "language"
@@ -862,8 +996,11 @@ testthat::test_that("setResourcesContractionsPath path type error",{
   path <- NULL
 
   testthat::expect_error(pipe$setResourcesContractionsPath(path),
-                         "[ContractionPipe][setResourcesContractionsPath][Error] Checking the type of the 'path' variable: NULL",
+                         "[ContractionPipe][setResourcesContractionsPath][FATAL] Checking the type of the 'path' variable: NULL",
                          fixed = TRUE)
 })
 
-testthat::teardown(bdpar.Options$reset())
+testthat::teardown({
+  bdpar.Options$reset()
+  bdpar.Options$configureLog()
+})
